Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(274)

Unified Diff: content/public/browser/resource_dispatcher_host.h

Issue 114193009: [Download] Return DownloadInterruptReason from OnStartedCallback (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/browser/download_url_parameters.h ('k') | content/public/test/download_test_observer.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/resource_dispatcher_host.h
diff --git a/content/public/browser/resource_dispatcher_host.h b/content/public/browser/resource_dispatcher_host.h
index 0d4a624f2e8c5c02cad488f35a3bf4e2bf4421f5..7db278c8aac7708cab11070aff054e3b76d3baa4 100644
--- a/content/public/browser/resource_dispatcher_host.h
+++ b/content/public/browser/resource_dispatcher_host.h
@@ -6,7 +6,8 @@
#define CONTENT_PUBLIC_BROWSER_RESOURCE_DISPATCHER_HOST_H_
#include "base/callback_forward.h"
-#include "net/base/net_errors.h"
+#include "base/memory/scoped_ptr.h"
+#include "content/public/browser/download_interrupt_reasons.h"
namespace net {
class URLRequest;
@@ -22,8 +23,8 @@ struct Referrer;
class CONTENT_EXPORT ResourceDispatcherHost {
public:
- typedef base::Callback<void(DownloadItem*, net::Error)>
- DownloadStartedCallback;
+ typedef base::Callback<void(DownloadItem*, DownloadInterruptReason)>
+ DownloadStartedCallback;
// Returns the singleton instance of the ResourceDispatcherHost.
static ResourceDispatcherHost* Get();
@@ -45,8 +46,8 @@ class CONTENT_EXPORT ResourceDispatcherHost {
// will be used. (Note that this will result in re-use of an existing
// download item if the download id was already assigned.) If the download
// is started, |started_callback| will be called on the UI thread with the
- // DownloadItem; otherwise an error code will be returned.
- virtual net::Error BeginDownload(
+ // DownloadItem; otherwise an interrupt reason will be returned.
+ virtual DownloadInterruptReason BeginDownload(
scoped_ptr<net::URLRequest> request,
const Referrer& referrer,
bool is_content_initiated,
« no previous file with comments | « content/public/browser/download_url_parameters.h ('k') | content/public/test/download_test_observer.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698